==> kdesdk-4.6.2.tar.bz2: kdesdk-4.6.2/okteta/libs/kasten/gui/shell/toolviewdockwidget.h <==
/*
    This file is part of the Kasten Framework, part of the KDE project.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef TOOLVIEWDOCKWIDGET_H
#define TOOLVIEWDOCKWIDGET_H

// Qt
#include <QtGui/QDockWidget>


namespace Kasten
{

class AbstractToolView;


class ToolViewDockWidget : public QDockWidget
{
   Q_OBJECT

  public:
    ToolViewDockWidget( AbstractToolView* mToolView, QWidget* parent );
    virtual ~ToolViewDockWidget();

  public:
    AbstractToolView* toolView() const;
    bool isShown() const;

  protected Q_SLOTS:
    void onVisibilityChanged( bool isVisible );

  protected:
    AbstractToolView* mToolView;
    // TODO: find out why isVisible does not work here
    bool mIsShown; 
};


inline AbstractToolView* ToolViewDockWidget::toolView() const { return mToolView; }
inline bool ToolViewDockWidget::isShown() const { return mIsShown; }

}

#endif

==> kdesdk-4.7.3.tar.bz2: kdesdk-4.7.3/okteta/libs/kasten/gui/shell/toolviewdockwidget.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef TOOLVIEWDOCKWIDGET_H
#define TOOLVIEWDOCKWIDGET_H

// Qt
#include <QtGui/QDockWidget>


namespace Kasten
{

class AbstractToolView;


class ToolViewDockWidget : public QDockWidget
{
   Q_OBJECT

  public:
    ToolViewDockWidget( AbstractToolView* mToolView, QWidget* parent );
    virtual ~ToolViewDockWidget();

  public:
    AbstractToolView* toolView() const;
    bool isShown() const;

  protected Q_SLOTS:
    void onVisibilityChanged( bool isVisible );

  protected:
    AbstractToolView* mToolView;
    // TODO: find out why isVisible does not work here
    bool mIsShown; 
};


inline AbstractToolView* ToolViewDockWidget::toolView() const { return mToolView; }
inline bool ToolViewDockWidget::isShown() const { return mIsShown; }

}

#endif
